pytilities

Package pytilities |
[hide private]
[frames] | no frames]

# Source Code for Package pytilities

     1  # Copyright (C) 2010 Tim Diels <limyreth@users.sourceforge.net>
     2  #
     3  # This file is part of pytilities.
     4  #
     5  # pytilities is free software: you can redistribute it and/or modify
     6  # it under the terms of the GNU General Public License as published by
     7  # the Free Software Foundation, either version 3 of the License, or
     8  # (at your option) any later version.
     9  #
    10  # pytilities is distributed in the hope that it will be useful,
    11  # but WITHOUT ANY WARRANTY; without even the implied warranty of
    12  # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    13  # GNU General Public License for more details.
    14  #
    15  # You should have received a copy of the GNU General Public License
    16  # along with pytilities.  If not, see <http://www.gnu.org/licenses/>.
    17  #
    18
    19  '''
    20  Root of pytilities, various utilities
    21
    22  Web site: http://pytilities.sourceforge.net/
    23  Sourceforge site: http://sourceforge.net/projects/pytilities/
    24
    25  Features:
    26
    27      - delegation: decorate classes with attributes that are delegated to a
    28      target object without having to write those attributes on the decorating
    29      class
    30
    31      - event dispatching: Observer/Subject like event dispatching with wrappers
    32      for hiding events on dispatchers and combining dispatchers
    33
    34      - function overloading
    35
    36      - various: Vector, Rectangle classes, custom types, ...
    37
    38  Classes:
    39
    40      - `AttributeCollection`: Abstract, represents a collection of attributes.
    41      - `AttributeCollectionBase`: Mixin, allows easy extension of class attributes
    42      - `Stringifiable`: Mixin, provides a reasonable default __str__
    43
    44  Functions:
    45
    46      - `mangle`: Get the mangled name of an attribute
    47  '''
    48
    49  __docformat__ = 'reStructuredText'
    50
    51  from .attributecollection import AttributeCollection
    52  from .attributecollectionbase import AttributeCollectionBase
    53  from .stringifiable import Stringifiable
    54  from .mangling import mangle
    55